{% load i18n %}

<!-- disable srp link -->
<div class="modal fade" id="disable-srp-link" tabindex="-1" role="dialog" aria-labelledby="{% translate 'Disable SRP Link' %}" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>

                <div class="modal-title">
                    {% translate "Disable SRP Link" %}
                </div>
            </div>

            <div class="modal-body"></div>

            <div class="modal-footer">
                <button type="button" class="btn btn-default btn-sm" data-dismiss="modal">
                    <i class="far fa-hand-paper"></i>
                    {% translate "Cancel" %}
                </button>

                <a id="modal-button-confirm-disable-srp-link" class="btn btn-warning btn-sm" role="button" href="">
                    <i class="fas fa-ban"></i>
                    {% translate "Disable" %}
                </a>
            </div>
        </div>
    </div>
</div>
